# Program:
#      Install Supermicro CIM Provider
# History:
# 20151124 Ray Kao

if [ "$1" != ""  ]; then
  if [ "$1" != "--AllowCommunitySupported" ]; then
       echo "SMC CIM Provider"
       echo "Copyright(c) 2016 Super Micro Computer, Inc."
       echo "Usage: SMC CIM Provider params (Example: ./install.sh --AllowCommunitySupported)"
       echo "  --AllowCommunitySupported       Set host acceptance level = CommunitySupported and install SMC CIM Provider"
       echo ""
       exit 0
  fi
else
  echo "SMC CIM Provider"
  echo "Copyright(c) 2016 Super Micro Computer, Inc."
  echo "Usage: SMC CIM Provider params (Example: ./install.sh --AllowCommunitySupported)"
  echo "  --AllowCommunitySupported       Set host acceptance level = CommunitySupported and install SMC CIM Provider"
  echo ""
  exit 0
fi                                                                                                                                                                                                                                            


esxcli software acceptance set --level=CommunitySupported
if [ $? != 0 ]; then
  echo "Set acceptance level fail, please check system priviledge"
  exit 0
fi

cDir=`pwd`
echo "Starting install Supermicro CIM Provider"

echo -n "Checking vib file .."
test ! -e "${cDir}/smc-cim-provider.vib" && echo "The vib file of SMC CIM Provider do not exist, please check it." && echo "Exit installation program." && exit 0 
echo " OK"

echo -n "Stop CIM service, please wait .."
/etc/init.d/sfcbd-watchdog stop >/dev/null 2&>1
test $? == 0 && echo " OK" || echo "Failure"

echo -n "Checking and removing the old version of SMC CIM Provider .."
esxcli software vib list | grep smc-cim-provider >/dev/null 2>&1
test $? == 0 && esxcli software vib remove -n smc-cim-provider >/dev/null 2>&1
echo " OK"


echo -n "Installing .."
esxcli software vib install -v "${cDir}/smc-cim-provider.vib" --no-sig-check >/dev/null 2>&1
if [ $? == 0 ]; then
	 echo " OK"
else
	 echo " "
	 echo "Installation failure, please try later."
	 exit 0
fi

echo -n "Start CIM Servcie .."
/etc/init.d/sfcbd-watchdog start > /dev/null 2&>1
sleep 3
if [ $? == 0 ]; then
	echo " OK"
else 
	echo " "
	echo "Failure"
fi

echo "List installed information .."
echo "---------------------------------------------------------------------------------------------------------------"
echo "Name                           Version                               Vendor      Acceptance Level  Install Date"
echo "-----------------------------  ------------------------------------  ----------  ----------------  ------------"
esxcli software vib list | grep smc-cim-provider
echo "---------------------------------------------------------------------------------------------------------------"
echo "Installation complete, please reboot the host."








